macro_rules! fixed_mul_div_assign {
($ty:ty) => { ... };
}Expand description
Implements multiplication and division assignment operators for fixed types.
macro_rules! fixed_mul_div_assign {
($ty:ty) => { ... };
}Implements multiplication and division assignment operators for fixed types.